/*
 *
 * @Component			OMAPCONF
 * @Filename			clock_dra7xx.h
 * @Description			DRA7 PRCM Clocks Definitions & Functions
 * @Author			Jin Zheng (j-zheng@ti.com)
 * @Date			2013
 * @Copyright			Texas Instruments Incorporated
 *
 *
 * Copyright (C) 2013 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */


#ifndef __PRCM_CLOCK_DRA7XX_H__
#define __PRCM_CLOCK_DRA7XX_H__

#define CLK_DRA7XX_MAX_NAME_LENGTH		32

typedef enum {
	/* 32K CLKS */
	CLK_DRA7XX_SYS_32K,
	CLK_DRA7XX_FUNC_32K_CLK,
	CLK_DRA7XX_SECURE_32K_CLK,
	CLK_DRA7XX_HDMI_CEC_GFCLK,
	CLK_DRA7XX_WKUPAON_32K_GFCLK,
	CLK_DRA7XX_COREAON_32K_GFCLK,
	CLK_DRA7XX_PER_32K_GFCLK,
	CLK_DRA7XX_ABE_32K_CLK,
	CLK_DRA7XX_MMC1_32K_GFCLK,
	/* SYS CLKS */
	CLK_DRA7XX_SYS_CLKIN1,
	CLK_DRA7XX_SYS_CLKIN2,
	CLK_DRA7XX_ABE_DPLL_SYS_CLK,
	CLK_DRA7XX_CUSTEFUSE_SYS_GFCLK,
	CLK_DRA7XX_EMU_SYS_CLK,
	CLK_DRA7XX_MPU_DPLL_CLK,
	CLK_DRA7XX_IVA_DPLL_CLK,
	CLK_DRA7XX_CORE_DPLL_CLK,
	CLK_DRA7XX_PER_DPLL_CLK,
	CLK_DRA7XX_EVE_DPLL_CLK,
	CLK_DRA7XX_DSP_DPLL_CLK,
	CLK_DRA7XX_GMAC_DPLL_CLK,
	CLK_DRA7XX_GPU_DPLL_CLK,
	CLK_DRA7XX_DDR_DPLL_CLK,
	CLK_DRA7XX_USB_DPLL_CLK,
	CLK_DRA7XX_PCIE_DPLL_CLK,
	CLK_DRA7XX_USB_OTG_SS_REF_CLK,
	CLK_DRA7XX_UNIPRO1_DPLL_CLK,
	CLK_DRA7XX_WKUPAON_IO_SRCOMP_GFCLK,
	CLK_DRA7XX_COREAON_IO_SRCOMP_GFCLK,
	CLK_DRA7XX_UNIPRO2_PHY_REF_GFCLK,
	CLK_DRA7XX_MIPIEXT_PHY_REF_GFCLK,
	CLK_DRA7XX_SATA_REF_GFCLK,
	CLK_DRA7XX_DSS_SYS_CLK,
	CLK_DRA7XX_ABE_SYS_CLK,
	/* DPLL BYPASS INPUT CLKS */
	CLK_DRA7XX_ABE_DPLL_CLK,
	CLK_DRA7XX_ABE_DPLL_BYPASS_CLK,
	CLK_DRA7XX_MPU_DPLL_HS_CLK,
	CLK_DRA7XX_IVA_DPLL_HS_CLK,
	CLK_DRA7XX_PER_DPLL_HS_CLK,
	CLK_DRA7XX_USB_DPLL_HS_CLK,
	CLK_DRA7XX_EVE_DPLL_HS_CLK,
	CLK_DRA7XX_DSP_DPLL_HS_CLK,
	CLK_DRA7XX_GMAC_DPLL_HS_CLK,
	CLK_DRA7XX_GPU_DPLL_HS_CLK,
	CLK_DRA7XX_DDR_DPLL_HS_CLK,
	/* DPLL HSDIV BYPASS CLK */
	CLK_DRA7XX_ABE_BYP_CLK_HMN,
	CLK_DRA7XX_MPU_BYP_CLK_HMN,
	CLK_DRA7XX_CORE_BYP_CLK_HMN,
	CLK_DRA7XX_IVA_BYP_CLK_HMN,
	CLK_DRA7XX_DDR_BYP_CLK_HMN,
	CLK_DRA7XX_EVE_BYP_CLK_HMN,
	CLK_DRA7XX_DSP_BYP_CLK_HMN,
	CLK_DRA7XX_GMAC_BYP_CLK_HMN,
	CLK_DRA7XX_GPU_BYP_CLK_HMN,
	CLK_DRA7XX_PER_BYP_CLK_HMN,
	CLK_DRA7XX_USB_BYP_CLK_HMN,
	CLK_DRA7XX_PCIE_BYP_CLK_HMN,
	/* DPLL ABE OUTPUT CLKS */
	CLK_DRA7XX_PER_ABE_X1_GFCLK,
	CLK_DRA7XX_DPLL_ABE_X2_FCLK,
	CLK_DRA7XX_CORE_DPLL_HS_CLK,
	/* DPLL CORE OUTPUTS */
	CLK_DRA7XX_CORE_DPLL_OUT_CLK,
	CLK_DRA7XX_CORE_X2_CLK,
	CLK_DRA7XX_CORE_USB_OTG_SS_LFPS_TX_CLK,
	CLK_DRA7XX_CORE_GPU_CLK,
	CLK_DRA7XX_CORE_IPU_ISS_BOOST_CLK,
	CLK_DRA7XX_CORE_ISS_MAIN_CLK,
	CLK_DRA7XX_BB2D_GFCLK,
	/* DPLL PER OUTPUTS */
	CLK_DRA7XX_FUNC_96M_AON_CLK,
	CLK_DRA7XX_FUNC_192M_FCLK,
	CLK_DRA7XX_FUNC_256M_CLK,
	CLK_DRA7XX_DSS_GFCLK,
	CLK_DRA7XX_PER_QSPI_CLK,
	CLK_DRA7XX_PER_GPU_CLK,
	/* DPLL MPU OUTPUTS */
	CLK_DRA7XX_MPU_GCLK,
	/* DPLL IVA OUTPUTS */
	CLK_DRA7XX_IVA_GCLK,
	/* DPLL USB OUTPUTS */
	CLK_DRA7XX_L3INIT_480M_GFCLK,
	CLK_DRA7XX_L3INIT_960M_GFCLK,
	/* DPLL EVE OUTPUTS */
	CLK_DRA7XX_EVE_GFCLK,
	/* DPLL DSP OUTPUTS */
	CLK_DRA7XX_DSP_GFCLK,
	CLK_DRA7XX_EVE_GCLK,
	/* DPLL GMAC OUTPUTS */
	CLK_DRA7XX_GMAC_250M_CLK,
	CLK_DRA7XX_ICSS_IEP_CLK,
	CLK_DRA7XX_GMAC_RMII_HS_CLK,
	CLK_DRA7XX_GMII_250MHZ_CLK,
	CLK_DRA7XX_ICSS_CLK,
	/* DPLL GPU OUTPUTS */
	CLK_DRA7XX_GPU_GCLK,
	/* DPLL DDR OUTPUTS */
	CLK_DRA7XX_EMIF_PHY_GCLK,
	CLK_DRA7XX_EMIF_DLL_GCLK,
	/* DPLL PCIE_REF OUTPUTS */
	CLK_DRA7XX_PCIE_M2_CLK,
	CLK_DRA7XX_PCIE_REF_CLK,
	/* COREAON CLKDM Clocks */
	CLK_DRA7XX_FUNC_24M_CLK,
	CLK_DRA7XX_FUNC_24M_GFCLK,
	CLK_DRA7XX_CORE_CLK,
	CLK_DRA7XX_L3_ICLK,
	CLK_DRA7XX_EMIF_L3_GICLK,
	CLK_DRA7XX_L4SEC_L3_GICLK,
	CLK_DRA7XX_CAM_L3_GICLK,
	CLK_DRA7XX_C2C_L3_GICLK,
	CLK_DRA7XX_DMA_L3_GICLK,
	CLK_DRA7XX_L3INSTR_L3_GICLK,
	CLK_DRA7XX_L3MAIN1_L3_GICLK,
	CLK_DRA7XX_L3MAIN2_L3_GICLK,
	CLK_DRA7XX_MIPIEXT_L3_GICLK,
	CLK_DRA7XX_DSS_L3_GICLK,
	CLK_DRA7XX_L3INIT_L3_GICLK,
	CLK_DRA7XX_CM_CORE_AON_PROFILING_L3_GICLK,
	CLK_DRA7XX_L4_ROOT_CLK,
	CLK_DRA7XX_L4_ICLK,
	CLK_DRA7XX_L4PER_L4_GICLK,
	CLK_DRA7XX_L4SEC_L4_GICLK,
	CLK_DRA7XX_C2C_L4_GICLK,
	CLK_DRA7XX_L4CFG_L4_GICLK,
	CLK_DRA7XX_MIPIEXT_L4_GICLK,
	CLK_DRA7XX_L3INIT_L4_GICLK,
	CLK_DRA7XX_CM_CORE_AON_PROFILING_L4_GICLK,
	/* PRM CLKDM Clocks */
	CLK_DRA7XX_ABE_LP_CLK,
	CLK_DRA7XX_WKUPAON_ICLK,
	CLK_DRA7XX_SR_MM_SYS_GFCLK,
	CLK_DRA7XX_SR_MPU_SYS_GFCLK,
	CLK_DRA7XX_SR_CORE_SYS_GFCLK,
	CLK_DRA7XX_WKUPAON_GCLK,
	CLK_DRA7XX_WKUPAON_GICLK,
	CLK_DRA7XX_CM_CORE_AON_SYS_CLK,
	CLK_DRA7XX_WKUPAON_PROFILING_GCLK,
	CLK_DRA7XX_CORE_TS_GFCLK,
	CLK_DRA7XX_COREAON_TS_GFCLK,
	CLK_DRA7XX_L3INSTR_DLL_AGING_GCLK,
	CLK_DRA7XX_L3INSTR_TS_GFCLK,
	/* PRM TIMER Clocks */
	CLK_DRA7XX_TIMER1_GFCLK,
	CLK_DRA7XX_TIMER2_GFCLK,
	CLK_DRA7XX_TIMER3_GFCLK,
	CLK_DRA7XX_TIMER4_GFCLK,
	CLK_DRA7XX_TIMER9_GFCLK,
	CLK_DRA7XX_TIMER10_GFCLK,
	CLK_DRA7XX_TIMER11_GFCLK,
	/* CKGEN_USB Clocks */
	CLK_DRA7XX_UTMI_P3_GFCLK,
	CLK_DRA7XX_HSIC_P3_GFCLK,
	CLK_DRA7XX_HSIC_P2_GFCLK,
	CLK_DRA7XX_HSIC_P1_GFCLK,
	CLK_DRA7XX_L3INIT_60M_P1_GFCLK,
	CLK_DRA7XX_L3INIT_60M_P2_GFCLK,
	CLK_DRA7XX_UTMI_ROOT_GFCLK,
	CLK_DRA7XX_TLL_CH0_GFCLK,
	CLK_DRA7XX_TLL_CH1_GFCLK,
	CLK_DRA7XX_TLL_CH2_GFCLK,
	CLK_DRA7XX_L3INIT_60M_FCLK,
	CLK_DRA7XX_HSIC_P1_480M_GFCLK,
	CLK_DRA7XX_HSIC_P2_480M_GFCLK,
	CLK_DRA7XX_HSIC_P3_480M_GFCLK,
	CLK_DRA7XX_XCLK_60M_HSP2,
	CLK_DRA7XX_XCLK_60M_HSP1,
	CLK_DRA7XX_UTMI_P1_GFCLK,
	CLK_DRA7XX_UTMI_P2_GFCLK,
	/* CKGEN_ABE Clocks */
	CLK_DRA7XX_PAD_UCLKS,
	CLK_DRA7XX_SLIMBUS_UCLKS,
	CLK_DRA7XX_ABE_CLK,
	CLK_DRA7XX_AESS_FCLK,
	CLK_DRA7XX_ABE_GICLK,
	CLK_DRA7XX_ABE_24M_FCLK,
	CLK_DRA7XX_PAD_GCLKS,
	CLK_DRA7XX_SLIMBUS_CLK,
	CLK_DRA7XX_MCBSP1_INT_GFCLK,
	CLK_DRA7XX_MCBSP2_INT_GFCLK,
	CLK_DRA7XX_MCBSP3_INT_GFCLK,
	CLK_DRA7XX_MCASP1_INT_GFCLK,
	CLK_DRA7XX_DMIC_INT_GFCLK,
	CLK_DRA7XX_MCBSP1_GFCLK,
	CLK_DRA7XX_MCBSP2_GFCLK,
	CLK_DRA7XX_MCBSP3_GFCLK,
	CLK_DRA7XX_MCASP1_GFCLK,
	CLK_DRA7XX_DMIC_GFCLK,
	CLK_DRA7XX_TIMER5_GFCLK,
	CLK_DRA7XX_TIMER6_GFCLK,
	CLK_DRA7XX_TIMER7_GFCLK,
	CLK_DRA7XX_TIMER8_GFCLK,
	/* CM_CORE Clocks */
	CLK_DRA7XX_GPU_HYD_GCLK,
	CLK_DRA7XX_GPU_CORE_GCLK,
	CLK_DRA7XX_FDIF_GFCLK,
	CLK_DRA7XX_PER_ABE_24M_FCLK,
	CLK_DRA7XX_FUNC_96M_FCLK,
	CLK_DRA7XX_FUNC_48M_FCLK,
	CLK_DRA7XX_FUNC_24M_FCLK,
	CLK_DRA7XX_HSI_FCLK,
	CLK_DRA7XX_FUNC_12M_FCLK,
	CLK_DRA7XX_MMC1_GFCLK,
	CLK_DRA7XX_MMC2_GFCLK,
	CLK_DRA7XX_PER_ABE_24M_GFCLK,
	CLK_DRA7XX_PER_96M_GFCLK,
	CLK_DRA7XX_PER_48M_GFCLK,
	CLK_DRA7XX_PER_24M_GFCLK,
	CLK_DRA7XX_HSI_GFCLK,
	CLK_DRA7XX_PER_12M_GFCLK,
	CLK_DRA7XX_C2C_GFCLK,
	CLK_DRA7XX_C2C_ICLK,
	CLK_DRA7XX_C2C_GICLK,
	CLK_DRA7XX_EMIF_LL_GCLK,
	CLK_DRA7XX_GPU_L3_GICLK,
	CLK_DRA7XX_DSS_L4_GICLK,
	/* Others */
	CLK_DRA7XX_IPU1_GFCLK,
	CLK_DRA7XX_IPU2_GFCLK,
	CLK_DRA7XX_EVE_CLK,
	CLK_DRA7XX_ID_MAX
} clk_dra7xx_id;


const char *clk_dra7xx_name_get(clk_dra7xx_id id);
double clk_dra7xx_rate_get(clk_dra7xx_id clk, unsigned short ignore);


#endif
