/*
 *
 * @Component			OMAPCONF
 * @Filename			display44xx.h
 * @Description			OMAP4 Display Configuration
 * @Author			Erwan Petillon (e-petillon@ti.com)
 * @Date			2011
 * @Copyright			Texas Instruments Incorporated
 *
 *
 * Copyright (C) 2011 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */


#ifndef __DISPLAY44XX_H__
#define __DISPLAY44XX_H__


/* DSS Physical address */
#define DSS_REVISION				0x58000000
#define DSS_SYSSTATUS				0x58000014
#define DSS_CTRL				0x58000040
#define DSS_STATUS				0x5800005C


/* DISPC Physical address */
#define DISPC_REVISION				0x58001000
#define DISPC_SYSCONFIG				0x58001010
#define DISPC_SYSSTATUS				0x58001014
#define DISPC_IRQSTATUS				0x58001018
#define DISPC_IRQENABLE				0x5800101C
#define DISPC_CONTROL1				0x58001040
#define DISPC_CONFIG1				0x58001044
#define DISPC_DEFAULT_COLOR0			0x5800104C
#define DISPC_DEFAULT_COLOR1			0x58001050
#define DISPC_TRANS_COLOR0			0x58001054
#define DISPC_TRANS_COLOR1			0x58001058
#define DISPC_LINE_STATUS			0x5800105C
#define DISPC_LINE_NUMBER			0x58001060
#define DISPC_TIMING_H1				0x58001064
#define DISPC_TIMING_V1				0x58001068
#define DISPC_POL_FREQ1				0x5800106C
#define DISPC_DIVISOR1				0x58001070
#define DISPC_GLOBAL_ALPHA			0x58001074
#define DISPC_SIZE_TV				0x58001078
#define DISPC_SIZE_LCD1				0x5800107C
#define DISPC_GFX_BA_0				0x58001080
#define DISPC_GFX_BA_1				0x58001084
#define DISPC_GFX_POSITION			0x58001088
#define DISPC_GFX_SIZE				0x5800108C
#define DISPC_GFX_ATTRIBUTES			0x580010A0
#define DISPC_GFX_BUF_THRESHOLD			0x580010A4
#define DISPC_GFX_BUF_SIZE_STATUS		0x580010A8
#define DISPC_GFX_ROW_INC			0x580010AC
#define DISPC_GFX_PIXEL_INC			0x580010B0
#define DISPC_GFX_WINDOW_SKIP			0x580010B4
#define DISPC_GFX_TABLE_BA			0x580010B8
#define DISPC_VID1_BA_0				0x580010BC
#define DISPC_VID1_BA_1				0x580010C0
#define DISPC_VID1_POSITION			0x580010C4
#define DISPC_VID1_SIZE				0x580010C8
#define DISPC_VID1_ATTRIBUTES			0x580010CC
#define DISPC_VID1_BUF_THRESHOLD		0x580010D0
#define DISPC_VID1_BUF_SIZE_STATUS		0x580010D4
#define DISPC_VID1_ROW_INC			0x580010D8
#define DISPC_VID1_PIXEL_INC			0x580010DC
#define DISPC_VID1_FIR				0x580010E0
#define DISPC_VID1_PICTURE_SIZE			0x580010E4
#define DISPC_VID1_ACCU_0			0x580010E8
#define DISPC_VID1_ACCU_1			0x580010EC
#define DISPC_VID1_FIR_COEF_H_0			0x580010F0
#define DISPC_VID1_FIR_COEF_H_1			0x580010F8
#define DISPC_VID1_FIR_COEF_H_2			0x58001100
#define DISPC_VID1_FIR_COEF_H_3			0x58001108
#define DISPC_VID1_FIR_COEF_H_4			0x58001110
#define DISPC_VID1_FIR_COEF_H_5			0x58001118
#define DISPC_VID1_FIR_COEF_H_6			0x58001120
#define DISPC_VID1_FIR_COEF_H_7			0x58001128
#define DISPC_VID1_FIR_COEF_HV_0		0x580010F4
#define DISPC_VID1_FIR_COEF_HV_1		0x580010FC
#define DISPC_VID1_FIR_COEF_HV_2		0x58001104
#define DISPC_VID1_FIR_COEF_HV_3		0x5800110C
#define DISPC_VID1_FIR_COEF_HV_4		0x58001114
#define DISPC_VID1_FIR_COEF_HV_5		0x5800111C
#define DISPC_VID1_FIR_COEF_HV_6		0x58001124
#define DISPC_VID1_FIR_COEF_HV_7		0x5800112C
#define DISPC_VID1_CONV_COEF0			0x58001130
#define DISPC_VID1_CONV_COEF1			0x58001134
#define DISPC_VID1_CONV_COEF2			0x58001138
#define DISPC_VID1_CONV_COEF3			0x5800113C
#define DISPC_VID1_CONV_COEF4			0x58001140
#define DISPC_VID2_BA_0				0x5800114C
#define DISPC_VID2_BA_1				0x58001150
#define DISPC_VID2_POSITION			0x58001154
#define DISPC_VID2_SIZE				0x58001158
#define DISPC_VID2_ATTRIBUTES			0x5800115C
#define DISPC_VID2_BUF_THRESHOLD		0x58001160
#define DISPC_VID2_BUF_SIZE_STATUS		0x58001164
#define DISPC_VID2_ROW_INC			0x58001168
#define DISPC_VID2_PIXEL_INC			0x5800116C
#define DISPC_VID2_FIR				0x58001170
#define DISPC_VID2_PICTURE_SIZE			0x58001174
#define DISPC_VID2_ACCU_0			0x58001178
#define DISPC_VID2_ACCU_1			0x5800117C
#define DISPC_VID2_FIR_COEF_H_0			0x58001180
#define DISPC_VID2_FIR_COEF_H_1			0x58001188
#define DISPC_VID2_FIR_COEF_H_2			0x58001190
#define DISPC_VID2_FIR_COEF_H_3			0x58001198
#define DISPC_VID2_FIR_COEF_H_4			0x580011A0
#define DISPC_VID2_FIR_COEF_H_5			0x580011A8
#define DISPC_VID2_FIR_COEF_H_6			0x580011B0
#define DISPC_VID2_FIR_COEF_H_7			0x580011B8
#define DISPC_VID2_FIR_COEF_HV_0		0x58001184
#define DISPC_VID2_FIR_COEF_HV_1		0x5800118C
#define DISPC_VID2_FIR_COEF_HV_2		0x58001194
#define DISPC_VID2_FIR_COEF_HV_3		0x5800119C
#define DISPC_VID2_FIR_COEF_HV_4		0x580011A4
#define DISPC_VID2_FIR_COEF_HV_5		0x580011AC
#define DISPC_VID2_FIR_COEF_HV_6		0x580011B4
#define DISPC_VID2_FIR_COEF_HV_7		0x580011BC
#define DISPC_VID2_CONV_COEF0			0x580011C0
#define DISPC_VID2_CONV_COEF1			0x580011C4
#define DISPC_VID2_CONV_COEF2			0x580011C8
#define DISPC_VID2_CONV_COEF3			0x580011CC
#define DISPC_VID2_CONV_COEF4			0x580011D0
#define DISPC_DATA1_CYCLE1			0x580011D4
#define DISPC_DATA1_CYCLE2			0x580011D8
#define DISPC_DATA1_CYCLE3			0x580011DC
#define DISPC_VID1_FIR_COEF_V_0			0x580011E0
#define DISPC_VID1_FIR_COEF_V_1			0x580011E4
#define DISPC_VID1_FIR_COEF_V_2			0x580011E8
#define DISPC_VID1_FIR_COEF_V_3			0x580011EC
#define DISPC_VID1_FIR_COEF_V_4			0x580011F0
#define DISPC_VID1_FIR_COEF_V_5			0x580011F4
#define DISPC_VID1_FIR_COEF_V_6			0x580011F8
#define DISPC_VID1_FIR_COEF_V_7			0x580011FC
#define DISPC_VID2_FIR_COEF_V_0			0x58001200
#define DISPC_VID2_FIR_COEF_V_1			0x58001204
#define DISPC_VID2_FIR_COEF_V_2			0x58001208
#define DISPC_VID2_FIR_COEF_V_3			0x5800120C
#define DISPC_VID2_FIR_COEF_V_4			0x58001210
#define DISPC_VID2_FIR_COEF_V_5			0x58001214
#define DISPC_VID2_FIR_COEF_V_6			0x58001218
#define DISPC_VID2_FIR_COEF_V_7			0x5800121C
#define DISPC_CPR1_COEF_R			0x58001220
#define DISPC_CPR1_COEF_G			0x58001224
#define DISPC_CPR1_COEF_B			0x58001228
#define DISPC_GFX_PRELOAD			0x5800122C
#define DISPC_VID1_PRELOAD			0x58001230
#define DISPC_VID2_PRELOAD			0x58001234
#define DISPC_CONTROL2				0x58001238
#define DISPC_VID3_ACCU_0			0x58001300
#define DISPC_VID3_ACCU_1			0x58001304
#define DISPC_VID3_BA_0				0x58001308
#define DISPC_VID3_BA_1				0x5800130C
#define DISPC_VID3_FIR_COEF_H_0			0x58001310
#define DISPC_VID3_FIR_COEF_H_1			0x58001318
#define DISPC_VID3_FIR_COEF_H_2			0x58001320
#define DISPC_VID3_FIR_COEF_H_3			0x58001328
#define DISPC_VID3_FIR_COEF_H_4			0x58001330
#define DISPC_VID3_FIR_COEF_H_5			0x58001338
#define DISPC_VID3_FIR_COEF_H_6			0x58001340
#define DISPC_VID3_FIR_COEF_H_7			0x58001348
#define DISPC_VID3_FIR_COEF_HV_0		0x58001314
#define DISPC_VID3_FIR_COEF_HV_1		0x5800131C
#define DISPC_VID3_FIR_COEF_HV_2		0x58001324
#define DISPC_VID3_FIR_COEF_HV_3		0x5800132C
#define DISPC_VID3_FIR_COEF_HV_4		0x58001334
#define DISPC_VID3_FIR_COEF_HV_5		0x5800133C
#define DISPC_VID3_FIR_COEF_HV_6		0x58001344
#define DISPC_VID3_FIR_COEF_HV_7		0x5800134C
#define DISPC_VID3_FIR_COEF_V_0			0x58001350
#define DISPC_VID3_FIR_COEF_V_1			0x58001354
#define DISPC_VID3_FIR_COEF_V_2			0x58001358
#define DISPC_VID3_FIR_COEF_V_3			0x5800135C
#define DISPC_VID3_FIR_COEF_V_4			0x58001360
#define DISPC_VID3_FIR_COEF_V_5			0x58001364
#define DISPC_VID3_FIR_COEF_V_6			0x58001368
#define DISPC_VID3_FIR_COEF_V_7			0x5800136C
#define DISPC_VID3_ATTRIBUTES			0x58001370
#define DISPC_VID3_CONV_COEF0			0x58001374
#define DISPC_VID3_CONV_COEF1			0x58001378
#define DISPC_VID3_CONV_COEF2			0x5800137C
#define DISPC_VID3_CONV_COEF3			0x58001380
#define DISPC_VID3_CONV_COEF4			0x58001384
#define DISPC_VID3_BUF_SIZE_STATUS		0x58001388
#define DISPC_VID3_BUF_THRESHOLD		0x5800138C
#define DISPC_VID3_FIR				0x58001390
#define DISPC_VID3_PICTURE_SIZE			0x58001394
#define DISPC_VID3_PIXEL_INC			0x58001398
#define DISPC_VID3_POSITION			0x5800139C
#define DISPC_VID3_PRELOAD			0x580013A0
#define DISPC_VID3_ROW_INC			0x580013A4
#define DISPC_VID3_SIZE				0x580013A8
#define DISPC_DEFAULT_COLOR2			0x580013AC
#define DISPC_TRANS_COLOR2			0x580013B0
#define DISPC_CPR2_COEF_B			0x580013B4
#define DISPC_CPR2_COEF_G			0x580013B8
#define DISPC_CPR2_COEF_R			0x580013BC
#define DISPC_DATA2_CYCLE1			0x580013C0
#define DISPC_DATA2_CYCLE2			0x580013C4
#define DISPC_DATA2_CYCLE3			0x580013C8
#define DISPC_SIZE_LCD2				0x580013CC
#define DISPC_TIMING_H2				0x58001400
#define DISPC_TIMING_V2				0x58001404
#define DISPC_POL_FREQ2				0x58001408
#define DISPC_DIVISOR2				0x5800140C
#define DISPC_WB_ACCU_0				0x58001500
#define DISPC_WB_ACCU_1				0x58001504
#define DISPC_WB_BA_0				0x58001508
#define DISPC_WB_BA_1				0x5800150C
#define DISPC_WB_FIR_COEF_H_0			0x58001510
#define DISPC_WB_FIR_COEF_H_1			0x58001518
#define DISPC_WB_FIR_COEF_H_2			0x58001520
#define DISPC_WB_FIR_COEF_H_3			0x58001528
#define DISPC_WB_FIR_COEF_H_4			0x58001530
#define DISPC_WB_FIR_COEF_H_5			0x58001538
#define DISPC_WB_FIR_COEF_H_6			0x58001540
#define DISPC_WB_FIR_COEF_H_7			0x58001548
#define DISPC_WB_FIR_COEF_HV_0			0x58001514
#define DISPC_WB_FIR_COEF_HV_1			0x5800151C
#define DISPC_WB_FIR_COEF_HV_2			0x58001524
#define DISPC_WB_FIR_COEF_HV_3			0x5800152C
#define DISPC_WB_FIR_COEF_HV_4			0x58001534
#define DISPC_WB_FIR_COEF_HV_5			0x5800153C
#define DISPC_WB_FIR_COEF_HV_6			0x58001544
#define DISPC_WB_FIR_COEF_HV_7			0x5800154C
#define DISPC_WB_FIR_COEF_V_0			0x58001550
#define DISPC_WB_FIR_COEF_V_1			0x58001554
#define DISPC_WB_FIR_COEF_V_2			0x58001558

#define DISPC_WB_FIR_COEF_V_3			0x5800155C
#define DISPC_WB_FIR_COEF_V_4			0x58001560
#define DISPC_WB_FIR_COEF_V_5			0x58001564
#define DISPC_WB_FIR_COEF_V_6			0x58001568
#define DISPC_WB_FIR_COEF_V_7			0x5800156C
#define DISPC_WB_ATTRIBUTES			0x58001570
#define DISPC_WB_CONV_COEF0			0x58001574
#define DISPC_WB_CONV_COEF1			0x58001578
#define DISPC_WB_CONV_COEF2			0x5800157C
#define DISPC_WB_CONV_COEF3			0x58001580
#define DISPC_WB_CONV_COEF4			0x58001584
#define DISPC_WB_BUF_SIZE_STATUS		0x58001588
#define DISPC_WB_BUF_THRESHOLD			0x5800158C
#define DISPC_WB_FIR				0x58001590
#define DISPC_WB_PICTURE_SIZE			0x58001594
#define DISPC_WB_PIXEL_INC			0x58001598
#define DISPC_WB_ROW_INC			0x580015A4
#define DISPC_WB_SIZE				0x580015A8
#define DISPC_VID1_BA_UV_0			0x58001600
#define DISPC_VID1_BA_UV_1			0x58001604
#define DISPC_VID2_BA_UV_0			0x58001608
#define DISPC_VID2_BA_UV_1			0x5800160C
#define DISPC_VID3_BA_UV_0			0x58001610
#define DISPC_VID3_BA_UV_1			0x58001614
#define DISPC_WB_BA_UV_0			0x58001618
#define DISPC_WB_BA_UV_1			0x5800161C
#define DISPC_CONFIG2				0x58001620
#define DISPC_VID1_ATTRIBUTES2			0x58001624
#define DISPC_VID2_ATTRIBUTES2			0x58001628
#define DISPC_VID3_ATTRIBUTES2			0x5800162C
#define DISPC_GAMMA_TABLE0			0x58001630
#define DISPC_GAMMA_TABLE1			0x58001634
#define DISPC_GAMMA_TABLE2			0x58001638
#define DISPC_VID1_FIR2				0x5800163C
#define DISPC_VID1_ACCU2_0			0x58001640
#define DISPC_VID1_ACCU2_1			0x58001644
#define DISPC_VID1_FIR2_COEF_H_0		0x58001648
#define DISPC_VID1_FIR2_COEF_H_1		0x58001650
#define DISPC_VID1_FIR2_COEF_H_2		0x58001658
#define DISPC_VID1_FIR2_COEF_H_3		0x58001660
#define DISPC_VID1_FIR2_COEF_H_4		0x58001668
#define DISPC_VID1_FIR2_COEF_H_5		0x58001670
#define DISPC_VID1_FIR2_COEF_H_6		0x58001678
#define DISPC_VID1_FIR2_COEF_H_7		0x58001680
#define DISPC_VID1_FIR2_COEF_HV_0		0x5800164C
#define DISPC_VID1_FIR2_COEF_HV_1		0x58001654
#define DISPC_VID1_FIR2_COEF_HV_2		0x5800165C
#define DISPC_VID1_FIR2_COEF_HV_3		0x58001664
#define DISPC_VID1_FIR2_COEF_HV_4		0x5800166C
#define DISPC_VID1_FIR2_COEF_HV_5		0x58001674
#define DISPC_VID1_FIR2_COEF_HV_6		0x5800167C
#define DISPC_VID1_FIR2_COEF_HV_7		0x58001684
#define DISPC_VID1_FIR2_COEF_V_0		0x58001688
#define DISPC_VID1_FIR2_COEF_V_1		0x5800168C
#define DISPC_VID1_FIR2_COEF_V_2		0x58001690
#define DISPC_VID1_FIR2_COEF_V_3		0x58001694
#define DISPC_VID1_FIR2_COEF_V_4		0x58001698
#define DISPC_VID1_FIR2_COEF_V_5		0x5800169C
#define DISPC_VID1_FIR2_COEF_V_6		0x580016A0
#define DISPC_VID1_FIR2_COEF_V_7		0x580016A4
#define DISPC_VID2_FIR2				0x580016A8
#define DISPC_VID2_ACCU2_0			0x580016AC
#define DISPC_VID2_ACCU2_1			0x580016B0
#define DISPC_VID2_FIR2_COEF_H_0		0x580016B4
#define DISPC_VID2_FIR2_COEF_H_1		0x580016BC
#define DISPC_VID2_FIR2_COEF_H_2		0x580016C4
#define DISPC_VID2_FIR2_COEF_H_3		0x580016CC
#define DISPC_VID2_FIR2_COEF_H_4		0x580016D4
#define DISPC_VID2_FIR2_COEF_H_5		0x580016DC
#define DISPC_VID2_FIR2_COEF_H_6		0x580016E4
#define DISPC_VID2_FIR2_COEF_H_7		0x580016EC
#define DISPC_VID2_FIR2_COEF_HV_0		0x580016B8
#define DISPC_VID2_FIR2_COEF_HV_1		0x580016C0
#define DISPC_VID2_FIR2_COEF_HV_2		0x580016C8
#define DISPC_VID2_FIR2_COEF_HV_3		0x580016D0
#define DISPC_VID2_FIR2_COEF_HV_4		0x580016D8
#define DISPC_VID2_FIR2_COEF_HV_5		0x580016E0
#define DISPC_VID2_FIR2_COEF_HV_6		0x580016E8
#define DISPC_VID2_FIR2_COEF_HV_7		0x580016F0
#define DISPC_VID2_FIR2_COEF_V_0		0x580016F4
#define DISPC_VID2_FIR2_COEF_V_1		0x580016F8
#define DISPC_VID2_FIR2_COEF_V_2		0x580016FC
#define DISPC_VID2_FIR2_COEF_V_3		0x58001700
#define DISPC_VID2_FIR2_COEF_V_4		0x58001704
#define DISPC_VID2_FIR2_COEF_V_5		0x58001708
#define DISPC_VID2_FIR2_COEF_V_6		0x5800170C
#define DISPC_VID2_FIR2_COEF_V_7		0x58001710
#define DISPC_VID3_FIR2				0x58001724
#define DISPC_VID3_ACCU2_0			0x58001728
#define DISPC_VID3_ACCU2_1			0x5800172C
#define DISPC_VID3_FIR2_COEF_H_0		0x58001730
#define DISPC_VID3_FIR2_COEF_H_1		0x58001738
#define DISPC_VID3_FIR2_COEF_H_2		0x58001740
#define DISPC_VID3_FIR2_COEF_H_3		0x58001748
#define DISPC_VID3_FIR2_COEF_H_4		0x58001750
#define DISPC_VID3_FIR2_COEF_H_5		0x58001758
#define DISPC_VID3_FIR2_COEF_H_6		0x58001760
#define DISPC_VID3_FIR2_COEF_H_7		0x58001768
#define DISPC_VID3_FIR2_COEF_HV_0		0x58001734
#define DISPC_VID3_FIR2_COEF_HV_1		0x5800173C
#define DISPC_VID3_FIR2_COEF_HV_2		0x58001744
#define DISPC_VID3_FIR2_COEF_HV_3		0x5800174C
#define DISPC_VID3_FIR2_COEF_HV_4		0x58001754
#define DISPC_VID3_FIR2_COEF_HV_5		0x5800175C
#define DISPC_VID3_FIR2_COEF_HV_6		0x58001764
#define DISPC_VID3_FIR2_COEF_HV_7		0x5800176C
#define DISPC_VID3_FIR2_COEF_V_0		0x58001770
#define DISPC_VID3_FIR2_COEF_V_1		0x58001774
#define DISPC_VID3_FIR2_COEF_V_2		0x58001778
#define DISPC_VID3_FIR2_COEF_V_3		0x5800177C
#define DISPC_VID3_FIR2_COEF_V_4		0x58001780
#define DISPC_VID3_FIR2_COEF_V_5		0x58001784
#define DISPC_VID3_FIR2_COEF_V_6		0x58001788
#define DISPC_VID3_FIR2_COEF_V_7		0x5800178C
#define DISPC_WB_FIR2				0x58001790
#define DISPC_WB_ACCU2_0			0x58001794
#define DISPC_WB_ACCU2_1			0x58001798
#define DISPC_WB_FIR2_COEF_H_0			0x580017A0
#define DISPC_WB_FIR2_COEF_H_1			0x580017A8
#define DISPC_WB_FIR2_COEF_H_2			0x580017B0
#define DISPC_WB_FIR2_COEF_H_3			0x580017B8
#define DISPC_WB_FIR2_COEF_H_4			0x580017C0
#define DISPC_WB_FIR2_COEF_H_5			0x580017C8
#define DISPC_WB_FIR2_COEF_H_6			0x580017D0
#define DISPC_WB_FIR2_COEF_H_7			0x580017D8
#define DISPC_WB_FIR2_COEF_HV_0			0x580017A4
#define DISPC_WB_FIR2_COEF_HV_1			0x580017AC
#define DISPC_WB_FIR2_COEF_HV_2			0x580017B4
#define DISPC_WB_FIR2_COEF_HV_3			0x580017BC
#define DISPC_WB_FIR2_COEF_HV_4			0x580017C4
#define DISPC_WB_FIR2_COEF_HV_5			0x580017CC
#define DISPC_WB_FIR2_COEF_HV_6			0x580017D4
#define DISPC_WB_FIR2_COEF_HV_7			0x580017DC
#define DISPC_WB_FIR2_COEF_V_0			0x580017E0
#define DISPC_WB_FIR2_COEF_V_1			0x580017E4
#define DISPC_WB_FIR2_COEF_V_2			0x580017E8
#define DISPC_WB_FIR2_COEF_V_3			0x580017EC
#define DISPC_WB_FIR2_COEF_V_4			0x580017F0
#define DISPC_WB_FIR2_COEF_V_5			0x580017F4
#define DISPC_WB_FIR2_COEF_V_6			0x580017F8
#define DISPC_WB_FIR2_COEF_V_7			0x580017FC
#define DISPC_GLOBAL_BUFFER			0x58001800
#define DISPC_DIVISOR				0x58001804
#define DISPC_WB_ATTRIBUTES2			0x58001810

/* DSI1 Physical address */
#define DSI1_REVISION				0x58004000
#define DSI1_SYSCONFIG				0x58004010
#define DSI1_SYSSTATUS				0x58004014
#define DSI1_IRQSTATUS				0x58004018
#define DSI1_IRQENABLE				0x5800401C
#define DSI1_CTRL				0x58004040
#define DSI1_GNQ				0x58004044
#define DSI1_COMPLEXIO_CFG1			0x58004048
#define DSI1_COMPLEXIO_IRQSTATUS		0x5800404C
#define DSI1_COMPLEXIO_IRQENABLE		0x58004050
#define DSI1_CLK_CTRL				0x58004054
#define DSI1_TIMING1				0x58004058
#define DSI1_TIMING2				0x5800405C
#define DSI1_VM_TIMING1				0x58004060
#define DSI1_VM_TIMING2				0x58004064
#define DSI1_VM_TIMING3				0x58004068
#define DSI1_CLK_TIMING				0x5800406C
#define DSI1_TX_FIFO_VC_SIZE			0x58004070
#define DSI1_RX_FIFO_VC_SIZE			0x58004074
#define DSI1_COMPLEXIO_CFG2			0x58004078
#define DSI1_RX_FIFO_VC_FULLNESS		0x5800407C
#define DSI1_VM_TIMING4				0x58004080
#define DSI1_TX_FIFO_VC_EMPTINESS		0x58004084
#define DSI1_VM_TIMING5				0x58004088
#define DSI1_VM_TIMING6				0x5800408C
#define DSI1_VM_TIMING7				0x58004090
#define DSI1_STOPCLK_TIMING			0x58004094
#define DSI1_CTRL2				0x58004098
#define DSI1_VM_TIMING8				0x5800409C
#define DSI1_TE_HSYNC_WIDTH_0			0x580040A0
#define DSI1_TE_VSYNC_WIDTH_0			0x580040A4
#define DSI1_TE_HSYNC_NUMBER_0			0x580040A8
#define DSI1_TE_HSYNC_WIDTH_1			0x580040AC
#define DSI1_TE_VSYNC_WIDTH_1			0x580040B0
#define DSI1_TE_HSYNC_NUMBER_1			0x580040B4
#define DSI1_VC_CTRL_1				0x58004100
#define DSI1_VC_TE_1				0x58004104
#define DSI1_VC_LONG_PACKET_HEADER_1		0x58004108
#define DSI1_VC_LONG_PACKET_PAYLOAD_1		0x5800410C
#define DSI1_VC_SHORT_PACKET_HEADER_1		0x58004110
#define DSI1_VC_IRQSTATUS_1			0x58004118
#define DSI1_VC_IRQENABLE_1			0x5800411C
#define DSI1_VC_CTRL_2				0x58004120
#define DSI1_VC_TE_2				0x58004124
#define DSI1_VC_LONG_PACKET_HEADER_2		0x58004128
#define DSI1_VC_LONG_PACKET_PAYLOAD_2		0x5800412C
#define DSI1_VC_SHORT_PACKET_HEADER_2		0x58004130
#define DSI1_VC_IRQSTATUS_2			0x58004138
#define DSI1_VC_IRQENABLE_2			0x5800413C
#define DSI1_VC_CTRL_3				0x58004140
#define DSI1_VC_TE_3				0x58004144
#define DSI1_VC_LONG_PACKET_HEADER_3		0x58004148
#define DSI1_VC_LONG_PACKET_PAYLOAD_3		0x5800414C
#define DSI1_VC_SHORT_PACKET_HEADER_3		0x58004150
#define DSI1_VC_IRQSTATUS_3			0x58004158
#define DSI1_VC_IRQENABLE_3			0x5800415C
#define DSI1_VC_CTRL_4				0x58004160
#define DSI1_VC_TE_4				0x58004164
#define DSI1_VC_LONG_PACKET_HEADER_4		0x58004168
#define DSI1_VC_LONG_PACKET_PAYLOAD_4		0x5800416C
#define DSI1_VC_SHORT_PACKET_HEADER_4		0x58004170
#define DSI1_VC_IRQSTATUS_4			0x58004178
#define DSI1_VC_IRQENABLE_4			0x5800417C

/* DSI1 PHY Physical address */
#define DSI1_PHY_REGISTER0			0x58004200
#define DSI1_PHY_REGISTER1			0x58004204
#define DSI1_PHY_REGISTER2			0x58004208
#define DSI1_PHY_REGISTER3			0x5800420C
#define DSI1_PHY_REGISTER4			0x58004210
#define DSI1_PHY_REGISTER5			0x58004214

/* DSI1 PLL Physical address */
#define DSI1_PLL_CONTROL			0x58004300
#define DSI1_PLL_STATUS				0x58004304
#define DSI1_PLL_GO				0x58004308
#define DSI1_PLL_CONFIGURATION1			0x5800430C
#define DSI1_PLL_CONFIGURATION2			0x58004310
#define DSI1_PLL_CONFIGURATION3			0x58004314
#define DSI1_PLL_SSC_CONFIGURATION1		0x58004318
#define DSI1_PLL_SSC_CONFIGURATION2		0x5800431C
#define DSI1_PLL_CONFIG				0x58004320

/* DSI2 Physical address */
#define DSI2_REVISION				0x58005000
#define DSI2_SYSCONFIG				0x58005010
#define DSI2_SYSSTATUS				0x58005014
#define DSI2_IRQSTATUS				0x58005018
#define DSI2_IRQENABLE				0x5800501C
#define DSI2_CTRL				0x58005040
#define DSI2_GNQ				0x58005044
#define DSI2_COMPLEXIO_CFG1			0x58005048
#define DSI2_COMPLEXIO_IRQSTATUS		0x5800504C
#define DSI2_COMPLEXIO_IRQENABLE		0x58005050
#define DSI2_CLK_CTRL				0x58005054
#define DSI2_TIMING1				0x58005058
#define DSI2_TIMING2				0x5800505C
#define DSI2_VM_TIMING1				0x58005060
#define DSI2_VM_TIMING2				0x58005064
#define DSI2_VM_TIMING3				0x58005068
#define DSI2_CLK_TIMING				0x5800506C
#define DSI2_TX_FIFO_VC_SIZE			0x58005070
#define DSI2_RX_FIFO_VC_SIZE			0x58005074
#define DSI2_COMPLEXIO_CFG2			0x58005078
#define DSI2_RX_FIFO_VC_FULLNESS		0x5800507C
#define DSI2_VM_TIMING4				0x58005080
#define DSI2_TX_FIFO_VC_EMPTINESS		0x58005084
#define DSI2_VM_TIMING5				0x58005088
#define DSI2_VM_TIMING6				0x5800508C
#define DSI2_VM_TIMING7				0x58005090
#define DSI2_STOPCLK_TIMING			0x58005094
#define DSI2_CTRL2				0x58005098
#define DSI2_VM_TIMING8				0x5800509C
#define DSI2_TE_HSYNC_WIDTH_0			0x580050A0
#define DSI2_TE_VSYNC_WIDTH_0			0x580050A4
#define DSI2_TE_HSYNC_NUMBER_0			0x580050A8
#define DSI2_TE_HSYNC_WIDTH_1			0x580050AC
#define DSI2_TE_VSYNC_WIDTH_1			0x580050B0
#define DSI2_TE_HSYNC_NUMBER_1			0x580050B4
#define DSI2_VC_CTRL_1				0x58005100
#define DSI2_VC_TE_1				0x58005104
#define DSI2_VC_LONG_PACKET_HEADER_1		0x58005108
#define DSI2_VC_LONG_PACKET_PAYLOAD_1		0x5800510C
#define DSI2_VC_SHORT_PACKET_HEADER_1		0x58005110
#define DSI2_VC_IRQSTATUS_1			0x58005118
#define DSI2_VC_IRQENABLE_1			0x5800511C
#define DSI2_VC_CTRL_2				0x58005120
#define DSI2_VC_TE_2				0x58005124
#define DSI2_VC_LONG_PACKET_HEADER_2		0x58005128
#define DSI2_VC_LONG_PACKET_PAYLOAD_2		0x5800512C
#define DSI2_VC_SHORT_PACKET_HEADER_2		0x58005130
#define DSI2_VC_IRQSTATUS_2			0x58005138
#define DSI2_VC_IRQENABLE_2			0x5800513C
#define DSI2_VC_CTRL_3				0x58005140
#define DSI2_VC_TE_3				0x58005144
#define DSI2_VC_LONG_PACKET_HEADER_3		0x58005148
#define DSI2_VC_LONG_PACKET_PAYLOAD_3		0x5800514C
#define DSI2_VC_SHORT_PACKET_HEADER_3		0x58005150
#define DSI2_VC_IRQSTATUS_3			0x58005158
#define DSI2_VC_IRQENABLE_3			0x5800515C
#define DSI2_VC_CTRL_4				0x58005160
#define DSI2_VC_TE_4				0x58005164
#define DSI2_VC_LONG_PACKET_HEADER_4		0x58005168
#define DSI2_VC_LONG_PACKET_PAYLOAD_4		0x5800516C
#define DSI2_VC_SHORT_PACKET_HEADER_4		0x58005170
#define DSI2_VC_IRQSTATUS_4			0x58005178
#define DSI2_VC_IRQENABLE_4			0x5800517C

/* DSI2 PHY Physical address */
#define DSI2_PHY_REGISTER0			0x58005200
#define DSI2_PHY_REGISTER1			0x58005204
#define DSI2_PHY_REGISTER2			0x58005208
#define DSI2_PHY_REGISTER3			0x5800520C
#define DSI2_PHY_REGISTER4			0x58005210
#define DSI2_PHY_REGISTER5			0x58005214

/* DSI2 PLL Physical address */
#define DSI2_PLL_CONTROL			0x58005300
#define DSI2_PLL_STATUS				0x58005304
#define DSI2_PLL_GO				0x58005308
#define DSI2_PLL_CONFIGURATION1			0x5800530C
#define DSI2_PLL_CONFIGURATION2			0x58005310
#define DSI2_PLL_CONFIGURATION3			0x58005314
#define DSI2_PLL_SSC_CONFIGURATION1		0x58005318
#define DSI2_PLL_SSC_CONFIGURATION2		0x5800531C
#define DSI2_PLL_CONFIG				0x58005320

/* RFBI Physical address */
#define RFBI_REVISION				0x58002000
#define RFBI_SYSCONFIG				0x58002010
#define RFBI_SYSSTATUS				0x58002014
#define RFBI_CONTROL				0x58002040
#define RFBI_PIXEL_CNT				0x58002044
#define RFBI_LINE_NUMBER			0x58002048
#define RFBI_CMD				0x5800204C
#define RFBI_PARAM				0x58002050
#define RFBI_DATA				0x58002054
#define RFBI_READ				0x58002058
#define RFBI_STATUS				0x5800205C
#define RFBI_CONFIG				0x58002060
#define RFBI_ONOFF_TIME				0x58002064
#define RFBI_CYCLE_TIME				0x58002068
#define RFBI_DATA_CYCLE0			0x5800206C
#define RFBI_DATA_CYCLE1			0x58002070
#define RFBI_DATA_CYCLE2			0x58002074
#define RFBI_DATA_CYCLE3			0x58002078
#define RFBI_DATA_CYCLE4			0x5800207C
#define RFBI_DATA_CYCLE5			0x58002080
#define RFBI_DATA_CYCLE6			0x58002084
#define RFBI_DATA_CYCLE7			0x58002088
#define RFBI_VSYNC_WIDTH			0x58002090
#define RFBI_HSYNC_WIDTH			0x58002094

/* VENC Physical address */
#define VENC_REV_ID				0x58003000
#define VENC_STATUS				0x58003004
#define VENC_F_CONTROL				0x58003008
#define VENC_VIDOUT_CTRL			0x58003010
#define VENC_SYNC_CTRL				0x58003014
#define VENC_LLEN				0x5800301C
#define VENC_FLENS				0x58003020
#define VENC_HFLTR_CTRL				0x58003024
#define VENC_CC_CARR_WSS_CARR			0x58003028
#define VENC_C_PHASE				0x5800302C
#define VENC_GAIN_U				0x58003030
#define VENC_GAIN_V				0x58003034
#define VENC_GAIN_Y				0x58003038
#define VENC_BLACK_LEVEL			0x5800303C
#define VENC_BLANK_LEVEL			0x58003040
#define VENC_X_COLOR				0x58003044
#define VENC_M_CONTROL				0x58003048
#define VENC_BSTAMP_WSS_DATA			0x5800304C
#define VENC_S_CARR				0x58003050
#define VENC_LINE21				0x58003054
#define VENC_LN_SEL				0x58003058
#define VENC_L21_WC_CTL				0x5800305C
#define VENC_HTRIGGER_VTRIGGER			0x58003060
#define VENC_SAVID_EAVID			0x58003064
#define VENC_FLEN_FAL				0x58003068
#define VENC_LAL_PHASE_RESET			0x5800306C
#define VENC_HS_INT_START_STOP_X		0x58003070
#define VENC_HS_EXT_START_STOP_X		0x58003074
#define VENC_VS_INT_START_X			0x58003078
#define VENC_VS_INT_STOP_X_VS_INT_START_Y	0x5800307C
#define VENC_VS_INT_STOP_Y_VS_EXT_START_X	0x58003080
#define VENC_VS_EXT_STOP_X_VS_EXT_START_Y	0x58003084
#define VENC_VS_EXT_STOP_Y			0x58003088
#define VENC_AVID_START_STOP_X			0x58003090
#define VENC_AVID_START_STOP_Y			0x58003094
#define VENC_FID_INT_START_X_FID_INT_START_Y	0x580030A0
#define VENC_FID_INT_OFFSET_Y_FID_EXT_START_X	0x580030A4
#define VENC_FID_EXT_START_Y_FID_EXT_OFFSET_Y	0x580030A8
#define VENC_TVDETGP_INT_START_STOP_X		0x580030B0
#define VENC_TVDETGP_INT_START_STOP_Y		0x580030B4
#define VENC_GEN_CTRL				0x580030B8
#define VENC_OUTPUT_CONTROL			0x580030C4
#define VENC_OUTPUT_TEST			0x580030C8


int display44xx_name2addr(char *name, unsigned int *addr);
int display44xx_dump(char *display_mod);


#endif
